require "utilities"

States = {
	Searching = 0,
	GoingTo = 1,
	-- TakeLoot = 2
}

box = {
	New = function(entity)
			local self = {
				ent = entity,
				targetPosition = {0, 0}, -- there: radius, angle of rotation with 2*pi = 1.0
				
				--currentOrientation = entity.orientation,
				
				searchRadius = 1,
				DefaultSearchRadius = 1,
				state = States.Searching,
				oresInRadius = {},
				lastOreRadius = 0,
				MovementSpeed = 2,
				ticksMined = 0,
			}
			
		setmetatable(self, {__index=box})
		return self
	end,

	Tick = function(self)
		st = self.state
		game.players[1].print("Tick " .. st)
		box.StateFunctions[st](self)
	end,
	


	FloatingText = function(self, text, color)
		local pos = self.ent.position or {0,0}
		local text = text or {"Text"}
		local color = color or {r = 1, g = 1, b = 1}
		--game.surfaces.nauvis.create_entity({name="flying-text", position=self.vehicle.position, text=text, color=color})
	--	game.surfaces[1].create_entity({name="flying-text", position=self.position, text=text, color=color})
		game.surfaces[1].create_entity{name="flying-text", position=pos, text=text, color={r=0.5,g=1,b=1}}
		
	end,
	
	
	FindRandomOreInRadius = function(self, radius)
		if radius ~= lastOreRadius then
			self.lastOreRadius = lastOreRadius
		--	self.oresInRadius = game.player.surface.find_entities_filtered{type = "resource", area = GetBoundingBox(self.vehicle.position, radius)}
		--	self.oresInRadius = game.player.surface.find_entities_filtered{type = "resource", area = GetBoundingBox(self.position, radius)}
			--if not self.position.x then self.position = {0, 0} end
			self.oresInRadius = game.surfaces[1].find_entities_filtered{type= "resource", area = GetBoundingBox(self.ent.position, radius)} -- gets all resources in the rectangle
		end
		
		if #self.oresInRadius < 1 then
			return false
		end
		
		local i = math.random(#self.oresInRadius)
		local ore = self.oresInRadius[i]
		
		-- No fluids.
		if game.entity_prototypes[ore.name].resource_category == "basic-fluid"
		-- No lava.
		or game.entity_prototypes[ore.name].resource_category == "lava-magma"
		-- No depleted resources that aren't infinite.
		or (ore.amount <= 0 and not game.entity_prototypes[ore.name].infiniteresource)
		-- No trees.
		-- or string.find(ore.name, "tree") 
		
		then
			-- Not a valid ore.
			ore = false
		end
		-- Remove from the results list.
		table.remove(self.oresInRadius, i)
		
		return ore
	end,
	
	
	SetTargetPosition = function(self, position)
		self.targetPosition = position
		
		--game.players[1].print("STP self.targetPosition = ".. self.targetPosition.x .. " - " .. self.targetPosition.y)
		--game.players[1].print("STP self.ent.position = ".. self.ent.position.x .. " - " .. self.ent.position.y)
		
		--local dPos = vector.subtract(position, self.vehicle.position)
		local dPos = vector.subtract(position, self.ent.position)
		
		
		self.targetDistance = vector.length(dPos)
		--self.targetHeading = vector.div(dPos, self.targetDistance) -- Normalized(dPos)
		if self.targetDistance > self.MovementSpeed then
			self.targetOrientation = DeltaposToOrientation(dPos)
		end
		self.onArrivalCallback = onArrivalCallback
		
		--game.player.print("Moving to location {" .. position.x .. ", " .. position.y .. "}")
		local text = "Moving to location {" .. position.x .. ", " .. position.y .. "}"
		--self:FloatingText(text)
	end,
	
	


	StateFunctions = {
		--------------------------------------------------++--------------------------------------------------
		--										  	   Searching											--
		--------------------------------------------------++--------------------------------------------------
		[States.Searching] = function(self)
			--self:FloatingText("Searching")
			local tries = 0
			local ore = false
			while not ore and tries < 10 do
				ore = self:FindRandomOreInRadius(self.searchRadius)
				--self:FloatingText("FindRandomOreInRadius")
				-- we get "ore"
				tries = tries + 1
			end
			
			if not ore then
				self.searchRadius = self.searchRadius + 5
				return
			end
			
			ore = FindNearestEntity(self.ent, self.oresInRadius)
			
			-- We've found ore, so reset search radius and ores for next time.
			self.searchRadius = self.DefaultSearchRadius
			self.oresInRadius = {}
			
			-- Go there.
			-- self:SetTargetPosition(ore.position, function(self) end)
			if ore then self.targetPosition = ore.position end
			self.state = States.GoingTo
			
			-- We haven't mined the new location yet.
			self.scoopsMined = 0
		end,
		--------------------------------------------------++--------------------------------------------------
		--										  	   GoingTo											--
		--------------------------------------------------++--------------------------------------------------
		[States.GoingTo] = function(self)
		
			--game.players[1].print("self.targetPosition = ".. self.targetPosition.x .. " - " .. self.targetPosition.y)
			--game.players[1].print("self.self.ent.position = ".. self.ent.position.x .. " - " .. self.ent.position.y)
			
			dPos = vector.subtract(self.targetPosition, self.ent.position)
			self.targetDistance = vector.length(dPos)
			self.targetHeading = vector.div(dPos, self.targetDistance) -- vector.normalized(dPos)
			
			-- if self.targetDistance < self.MovementSpeed then
				-- self.teleport(self.targetPosition)
				-- -- This should set the new state.
				-- self.onArrivalCallback(self)
				-- return
			-- end
			
			local vmul = vector.mul(self.targetHeading, self.MovementSpeed)
			
			local teleportto = vector.add(self.ent.position, vmul)
			

			
			local goleft = {self.ent.position.x + 1/60, self.ent.position.y} 
			teleportto = goleft
		
			game.players[1].print("ent.position = " .. self.ent.position.x .. " - " .. self.ent.position.y)
			game.players[1].print("teleportto = " .. teleportto[1] .. " - " .. teleportto[2])
			
			self.ent.teleport({teleportto[1], teleportto[2]})
			
			--self.targetDistance = self.targetDistance - self.MovementSpeed
			
			self.state = States.Searching
			
			return
			
		end,
		
		--------------------------------------------------++--------------------------------------------------
		--										  	   TakeLoot											--
		--------------------------------------------------++--------------------------------------------------
		[States.TakeLoot] = function(self)
		
		
			
		end,

	},
}
